"""

:Author: Franziska Koehn
:Created: 2015/01/13

This module houses functions relating to the chart-creation.

"""

def count_substrings(substrings, strings):
    """
    Returns a dictionary including the counts of its keys.
    This keys are the given list of substrings.

    **Parameters**
        :substrings: list of str, list of substrings to be counted
        :strings:    list of str, strings in which the counts of substrings will be determined
    """
    from collections import defaultdict
    from itertools import product

    if strings == []:
        return []

    results = defaultdict(int)
    for sub,string in product(substrings, strings):
        results[sub] # create key
        if sub.lower() in string.lower():
            results[sub] += 1
    return list(results.items())


def create(file, data, size, y_max, x_max):
    """
    creates diagram for given 'data' and max-values ('y_max', 'x_max') and
    renders it as an image, saved as 'file' in given 'size'

    **Parameters**
        :file: destination/filename where the rendered image will be saved
        :data: dictionary, the key will be shown on the x-axis. the value on the y-axis. if a two-dimensional list will be pass, the values on the first dimension will drawn on the x-axis, the second on the y-axis
        :size: tuple (int,int), size of rendered image
        :y_max: max-value for y-axis
        :x_max: max-value for x-axis (= count of keys)
    """
    import matplotlib.pyplot as plt

    GNOME_BLUE = '#3A81CC'  # the proper gtk-widgets-colour
    DPI = float(90)         # dots per inch
    BAR_WIDTH = 0.8         # width of bars
    BAR_START = 0.1         # start of bars

    w, h = size
    labels = []
    values = []
    for lab, val in data:
        labels.append(lab)
        values.append(val)

    label_pos = []
    x_pos = []
    for x in range(len(labels)):
        label_pos.append(x+BAR_START+BAR_WIDTH/2)
        x_pos.append(x+BAR_START)

    _, ax = plt.subplots()

    if y_max != 0:
        plt.ylim((0,y_max))
        plt.xlim((0,x_max))
    else:
        plt.gca().axes.get_yaxis().set_visible(False)

    bars = plt.bar(left=x_pos, height=values, width=BAR_WIDTH, color=GNOME_BLUE)
    plt.xticks(label_pos, labels)
    plt.ylabel('Count')
    plt.gcf().set_size_inches(w/DPI,h/DPI)

    for b in bars:
        height = b.get_height()
        ax.text(b.get_x()+b.get_width()/2., height, '%d'%int(height),
                ha='center', va='bottom', color='black')


    plt.savefig(file, dpi=DPI,transparent=False, pad_inches=0, frameon=None)
    plt.close()
